#pragma once

#include <iostream>
#include <vector>


#include "include/slam_manager.h"

enum class INSStatus : uint8_t {
    INACTIVE = 0,      // INS 未激活，未有有效数据输出
    ALIGNING = 1,      // 正在校准中
    HIGH_VARIANCE = 2, // 方差较大，正在收敛
    SOLUTION_GOOD = 3, // 解算良好
    // ... and other statuses as needed
    SOLUTION_FREE = 6  // 自由解算模式
};

enum class PositionType : uint8_t {
    NONE = 0,          // 无效
    FIXEDPOS = 1,      // 固定位置 FIX POSITION 模式定位
    FIXEDHEIGHT = 2,    // 固定大地高
                        // ... Other types based on the document
    DOPPLER_VELOCITY = 8, // 多普勒速度
    SINGLE = 16,          // 单点定位
    PSRDIFF = 17,         // 伪距差分
    L1_FLOAT = 32,        // L1 浮点解
    IONOFREE_FLOAT = 33,  // 电离层消除浮点解
    NARROW_FLOAT = 34,    // 窄巷浮点解
    L1_INT = 48,          // L1 整周解
    WIDE_INT = 49,        // 宽巷整周解
    NARROW_INT = 50,      // 窄巷整周解
    INS_PSRSP = 53,       // 惯导与伪距 GNSS 单点定位组合定位 (天组网 DGNS)
    INS_PSRDIFF = 54,     // 惯导与伪距 DGNS 定位组合定位
    INS_RTKFLOAT = 55,    // 惯导与 GNSS RTK 浮点解组合定位
    INS_RTKFIXED = 56     // 惯导与 GNSS RTK 固定解组合定位
};

enum class TimeStatus : uint8_t {
    UNKNOWN = 0,        // 时间状态不可用
    APPROXIMATE = 60,   // 估算时间，多层由外部 RTC 同步获得
    COARSE = 100,       // GNSS 时间初略同步状态，粗略对准卫星秒脉冲
    COARSESTEERING = 120, // 接收机处于初略调整接收机时间状态
    FINE = 160,         // GNSS 时间同步精调状态，精准对准卫星秒脉冲
    FINESTEERING = 180, // 接收机处于精调调整接收机时间状态，精准对准卫星秒脉冲
    SATTIME = 200       // 从卫星接收卫星时钟的时间，仅用于星间链路同步
};

struct LogHeader {
    char sync;                 // Sync character
    std::string message;       // Message ID
    char port;                 // Port ID
    uint32_t sequence_number;  // Sequence number
    float idle_time;           // Idle time
    TimeStatus time_status;    // Time status
    uint32_t week;             // GPS week number
    double seconds;            // GPS seconds
    uint32_t receiver_status;  // Receiver status
    uint32_t reserved;         // Reserved for future use
    uint16_t firmware_version; // Firmware version
};

struct INSPVAXA {
    LogHeader header;
    INSStatus ins_status;
    PositionType pos_type;
    double latitude;
    double longitude;
    double height;
    float undulation;
    double north_velocity;
    double east_velocity;
    double up_velocity;
    double roll;
    double pitch;
    double azimuth;
    float latitude_std_dev;
    float longitude_std_dev;
    float height_std_dev;
    float north_velocity_std_dev;
    float east_velocity_std_dev;
    float up_velocity_std_dev;
    float roll_std_dev;
    float pitch_std_dev;
    float azimuth_std_dev;
    uint32_t extended_solution_status;
    uint32_t time_since_update;
};

class InspvaxaData
{
public:

    INSPVAXA parseINSPVAXA(std::string data);
    slam::InsData MapINSPVAXAToInsData(const INSPVAXA& inp);
private:


};

